==> web-10.0.0.tgz: package/lib/animate/Animate.js <==
import * as React from "react";
import { tween } from "./tween";
const animateTypeArr = ["fadeIn", "fadeOut", "bounceRightIn", "bounceDownIn", "bounceDownOut"];
const domAnimateProps = ["opacity", "width", "height", "transform"];
const easeTypeObj = {
    "fadeIn": "easeOutCubic",
    "fadeOut": "easeOutCubic",
    "bounceRightIn": "easeOutBack",
    "bounceDownIn": "easeOutBack",
    "bounceDownOut": "easeInBack",
};
class Animate extends React.PureComponent {
    constructor(props) {
        super(props);
        this.timer = 0;
        this.boxDom = React.createRef();
        this.state = {};
        this.animateState = {};
        const { animation } = props;
        this.valideAnimation(animation);
        this.easeType = this.registerEaseType(animation);
    }
    valideAnimation(animation) {
        if (typeof animation === "string") {
            if (!animateTypeArr.includes(animation)) {
                throw new Error('不存在改动画名称！请使用' + animateTypeArr.join('，') + "这些动画名称!");
            }
        }
        else if (typeof animation === "object") {
            const status = Object.keys(animation).some((val) => !domAnimateProps.includes(val));
            if (status) {
                throw new Error('不存在该动画属性！请使用' + domAnimateProps.join('，') + "这些动画属性!");
            }
        }
    }
    componentDidMount() {
        const { runMount, animation, duration } = this.props;
        const run = runMount ? "start" : undefined;
        this.animateState = this.getStart(animation, this.boxDom.current, run);
        if (runMount) {
            this.domExcute(this.boxDom.current, animation, duration, runMount);
        }
        else {
            this.initAnimateStateToDom(animation, this.boxDom.current);
        }
    }
    registerEaseType(animation) {
        if (typeof animation === "string") {
            return easeTypeObj[animation];
        }
        return "easeOutCubic";
    }
    initAnimateStateToDom(animation, dom) {
        if (typeof animation === "string") {
            const show = animation.includes("In");
            if (animation === "bounceRightIn") {
                dom.style.transform = `translateX(${dom.clientWidth}px)`;
            }
            dom.style.opacity = show ? "1" : "0";
            dom.style.display = show ? this.props.display : "none";
        }
        else {
            Object.keys(animation).map((key) => {
                const val = animation[key];
                if (key === "transform") {
                    dom.style.transform = val;
                }
                dom.style[key] = `${val}px`;
            });
        }
    }
    getStart(animation, dom, runMount) {
        const animateStateObj = {};
        dom.style.display = this.props.display;
        if (typeof animation === "string") {
            const show = animation.includes("In");
            if (animation === "bounceRightIn") {
                if (runMount) {
                    animateStateObj.transform = runMount === "end" ? 0 : dom.clientWidth;
                }
                else {
                    animateStateObj.transform = 0;
                }
            }
            else if (animation.includes("bounceDown")) {
                if (runMount) {
                    animateStateObj.transform = show ? runMount === "end" ? 0 : -dom.clientHeight : runMount === "end" ? dom.clientHeight : 0;
                }
                else {
                    animateStateObj.transform = show ? 0 : dom.clientHeight;
                }
            }
            if (runMount) {
                animateStateObj.opacity = show ? runMount === "end" ? 1 : 0 : runMount === "end" ? 0 : 1;
            }
            else {
                animateStateObj.opacity = show ? 1 : 0;
            }
        }
        else {
            Object.keys(animation).map((key) => {
                const val = animation[key];
                if (key === "transform") {
                    const translate = val.match(/-?\d+/g);
                    animateStateObj.transform = runMount === "start" ? [0, 0]
                        : translate ? [Number(translate[0]), Number(translate[1] || 0)] : [0, 0];
                }
                else {
                    animateStateObj[key] = runMount === "start" ? 0 : Number(val);
                }
            });
        }
        return animateStateObj;
    }
    domExcute(dom, animation, duration, runMout) {
        if (this.timer) {
            window.cancelAnimationFrame(this.timer);
            this.timer = 0;
        }
        const timeEnd = Math.ceil(duration / 10);
        const animationType = typeof animation === "string" ? animation : "objIn";
        const show = animationType.includes("In");
        let time = 0;
        const start = this.animateState;
        const endObj = this.getStart(animation, dom, runMout ? "end" : undefined);
        const fn = () => {
            this.timer = window.requestAnimationFrame(() => {
                Object.keys(this.animateState).forEach((val) => {
                    const key = val;
                    const ease = this.easeType;
                    if (key === "transform") {
                        if (animationType === "objIn") {
                            const transformB = start.transform;
                            const transformE = endObj.transform;
                            console.log(transformB, transformE, "domEx");
                            let distanceX = tween[ease](time, transformB[0], transformE[0], timeEnd);
                            let distanceY = tween[ease](time, transformB[1], transformE[1], timeEnd);
                            dom.style.transform = `translate(${distanceX}px, ${distanceY}px)`;
                        }
                        else {
                            const distance = tween[ease](time, start[key], endObj[key], timeEnd);
                            dom.style.transform = animationType.includes("Down") ? `translate(0px,${distance}px)` : `translate(${distance}px, 0px)`;
                        }
                    }
                    else {
                        const distance = `${tween[ease](time, start[key], endObj[key], timeEnd)}`;
                        dom.style[key] = distance + (key === "opacity" ? "" : "px");
                    }
                });
                if (time < timeEnd) {
                    fn();
                }
                else {
                    dom.style.display = show ? this.props.display : "none";
                    if (animationType.includes("bounce")) {
                        dom.style.transform = "translate(0px, 0px)";
                    }
                    this.timer = 0;
                }
                time++;
            });
        };
        fn();
        if (!runMout && animationType === "objIn") {
            this.animateState = endObj;
        }
    }
    componentDidUpdate(preProps) {
        const { animation, duration, runMount } = this.props;
        if (typeof animation === "string") {
            if (animation !== preProps.animation) {
                this.easeType = this.registerEaseType(animation);
                this.animateState = this.getStart(animation, this.boxDom.current, "start");
                this.domExcute(this.boxDom.current, animation, duration);
            }
        }
        else {
            const compare = Object.keys(animation).some((val) => {
                const k = val;
                return animation[k] !== preProps.animation[k];
            });
            if (compare) {
                this.easeType = this.registerEaseType(animation);
                if (runMount || typeof preProps.animation === "string") {
                    this.animateState = this.getStart(animation, this.boxDom.current, "start");
                }
                this.domExcute(this.boxDom.current, animation, duration);
            }
        }
    }
    componentWillUnmount() {
        if (this.timer) {
            window.cancelAnimationFrame(this.timer);
        }
    }
    render() {
        const { children, className, spanWrapEle, runMount, animation, styleObj } = this.props;
        const show = typeof animation === "string" && animation.includes("In") ? true : true;
        const opacity = typeof animation === "string" ? runMount ? show ? "0" : "1" : show ? "1" : "0" : "1";
        const style = Object.assign({ opacity: opacity, }, styleObj);
        return !spanWrapEle ? (React.createElement("div", { className: className, ref: this.boxDom, style: style }, children)) : (React.createElement("span", { className: className, style: style, ref: this.boxDom }, children));
    }
}
Animate.defaultProps = {
    duration: 300,
    elementStr: "div",
    className: "",
    display: "block"
};
export default Animate;

==> web-11.0.2.tgz: package/lib/animate/Animate.js <==
import * as React from "react";
import { tween } from "./tween";
const animateTypeArr = ["fadeIn", "fadeOut", "bounceRightIn", "bounceDownIn", "bounceDownOut"];
const domAnimateProps = ["opacity", "width", "height", "transform"];
const easeTypeObj = {
    "fadeIn": "easeOutCubic",
    "fadeOut": "easeOutCubic",
    "bounceRightIn": "easeOutBack",
    "bounceDownIn": "easeOutBack",
    "bounceDownOut": "easeInBack",
};
class Animate extends React.PureComponent {
    constructor(props) {
        super(props);
        this.timer = 0;
        this.boxDom = React.createRef();
        this.state = {};
        this.animateState = {};
        const { animation } = props;
        this.valideAnimation(animation);
        this.easeType = this.registerEaseType(animation);
    }
    valideAnimation(animation) {
        if (typeof animation === "string") {
            if (!animateTypeArr.includes(animation)) {
                throw new Error('不存在改动画名称！请使用' + animateTypeArr.join('，') + "这些动画名称!");
            }
        }
        else if (typeof animation === "object") {
            const status = Object.keys(animation).some((val) => !domAnimateProps.includes(val));
            if (status) {
                throw new Error('不存在该动画属性！请使用' + domAnimateProps.join('，') + "这些动画属性!");
            }
        }
    }
    componentDidMount() {
        const { runMount, animation, duration } = this.props;
        const run = runMount ? "start" : undefined;
        this.animateState = this.getStart(animation, this.boxDom.current, run);
        if (runMount) {
            this.domExcute(this.boxDom.current, animation, duration, runMount);
        }
        else {
            this.initAnimateStateToDom(animation, this.boxDom.current);
        }
    }
    registerEaseType(animation) {
        if (typeof animation === "string") {
            return easeTypeObj[animation];
        }
        return "easeOutCubic";
    }
    initAnimateStateToDom(animation, dom) {
        if (typeof animation === "string") {
            const show = animation.includes("In");
            if (animation === "bounceRightIn") {
                dom.style.transform = `translateX(${dom.clientWidth}px)`;
            }
            dom.style.opacity = show ? "1" : "0";
            dom.style.display = show ? this.props.display : "none";
        }
        else {
            Object.keys(animation).map((key) => {
                const val = animation[key];
                if (key === "transform") {
                    dom.style.transform = val;
                }
                dom.style[key] = `${val}px`;
            });
        }
    }
    getStart(animation, dom, status) {
        const animateStateObj = {};
        dom.style.display = this.props.display;
        if (typeof animation === "string") {
            const show = animation.includes("In");
            if (animation === "bounceRightIn") {
                if (status) {
                    animateStateObj.transform = status === "end" ? 0 : dom.clientWidth;
                }
                else {
                    animateStateObj.transform = 0;
                }
            }
            else if (animation.includes("bounceDown")) {
                if (status) {
                    animateStateObj.transform = show ? status === "end" ? 0 : -dom.clientHeight : status === "end" ? dom.clientHeight : 0;
                }
                else {
                    animateStateObj.transform = show ? 0 : dom.clientHeight;
                }
            }
            if (status) {
                animateStateObj.opacity = show ? status === "end" ? 1 : 0 : status === "end" ? 0 : 1;
            }
            else {
                animateStateObj.opacity = show ? 1 : 0;
            }
        }
        else {
            Object.keys(animation).map((key) => {
                const val = animation[key];
                if (key === "transform") {
                    const translate = val.match(/-?\d+/g);
                    animateStateObj.transform = status === "start" ? [0, 0]
                        : translate ? [Number(translate[0]), Number(translate[1] || 0)] : [0, 0];
                }
                else if ((key === "width" || key === "height") && val === "auto") {
                    animateStateObj[key] = status === "start" ? 0 : key === "width" ? dom.firstElementChild.clientWidth : dom.firstElementChild.clientHeight;
                }
                else {
                    animateStateObj[key] = status === "start" ? 0 : Number(val);
                }
            });
        }
        return animateStateObj;
    }
    domExcute(dom, animation, duration, runMout) {
        if (this.timer) {
            window.cancelAnimationFrame(this.timer);
            this.timer = 0;
        }
        const timeEnd = Math.ceil(duration / 10);
        const animationType = typeof animation === "string" ? animation : "objIn";
        let time = 0;
        const start = this.animateState;
        const endObj = this.getStart(animation, dom, runMout ? "end" : undefined);
        const show = animationType === "objIn" ? !Object.keys(endObj).some((key) => ["width", "height"].includes(key) && endObj[key] === 0) : animationType.includes("In");
        const fn = () => {
            this.timer = window.requestAnimationFrame(() => {
                Object.keys(this.animateState).forEach((val) => {
                    const key = val;
                    const ease = this.easeType;
                    if (key === "transform") {
                        if (animationType === "objIn") {
                            const transformB = start.transform;
                            const transformE = endObj.transform;
                            console.log(transformB, transformE, "domEx");
                            let distanceX = tween[ease](time, transformB[0], transformE[0], timeEnd);
                            let distanceY = tween[ease](time, transformB[1], transformE[1], timeEnd);
                            dom.style.transform = `translate(${distanceX}px, ${distanceY}px)`;
                        }
                        else {
                            const distance = tween[ease](time, start[key], endObj[key], timeEnd);
                            dom.style.transform = animationType.includes("Down") ? `translate(0px,${distance}px)` : `translate(${distance}px, 0px)`;
                        }
                    }
                    else {
                        const distance = `${tween[ease](time, start[key], endObj[key], timeEnd)}`;
                        dom.style[key] = distance + (key === "opacity" ? "" : "px");
                    }
                });
                if (time < timeEnd) {
                    fn();
                }
                else {
                    dom.style.display = show ? this.props.display : "none";
                    if (animationType.includes("bounce")) {
                        dom.style.transform = "translate(0px, 0px)";
                    }
                    this.timer = 0;
                }
                time++;
            });
        };
        fn();
        if (!runMout && animationType === "objIn") {
            this.animateState = endObj;
        }
    }
    componentDidUpdate(preProps) {
        const { animation, duration, runMount } = this.props;
        if (typeof animation === "string") {
            if (animation !== preProps.animation) {
                this.easeType = this.registerEaseType(animation);
                this.animateState = this.getStart(animation, this.boxDom.current, "start");
                this.domExcute(this.boxDom.current, animation, duration);
            }
        }
        else {
            const compare = Object.keys(animation).some((val) => {
                const k = val;
                return animation[k] !== preProps.animation[k];
            });
            if (compare) {
                this.easeType = this.registerEaseType(animation);
                if (runMount || typeof preProps.animation === "string") {
                    this.animateState = this.getStart(animation, this.boxDom.current, "start");
                }
                this.domExcute(this.boxDom.current, animation, duration);
            }
        }
    }
    componentWillUnmount() {
        if (this.timer) {
            window.cancelAnimationFrame(this.timer);
        }
    }
    render() {
        const { children, className, spanWrapEle, runMount, animation, styleObj } = this.props;
        const show = typeof animation === "string" && animation.includes("In") ? true : true;
        const opacity = typeof animation === "string" ? runMount ? show ? "0" : "1" : show ? "1" : "0" : "1";
        const style = Object.assign({ opacity: opacity, }, styleObj);
        return !spanWrapEle ? (React.createElement("div", { className: className, ref: this.boxDom, style: style }, children)) : (React.createElement("span", { className: className, style: style, ref: this.boxDom }, children));
    }
}
Animate.defaultProps = {
    duration: 300,
    elementStr: "div",
    className: "",
    display: "block"
};
export default Animate;
